PromptTemplate class abstract
Abstract base class for all prompt templates.
Templates responsible for formatting messages into a single prompt string that the specific LLM architecture expects.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stopSequence → String
-
The sequence that signals the model to stop generating.
no setter
Methods
-
formatMessages(
List< AgentChatMessage> messages) → String -
Formats a list of
messagesinto a raw prompt string. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited